PatchEntry

Trait PatchEntry 

pub trait PatchEntry: Send + Sync {
    // Required methods
    fn init(&mut self) -> Result<(), PatchError>;
    fn teardown(&mut self);
}
Optional entry point for patches with initialization/teardown

Required Methods

fn init(&mut self) -> Result<(), PatchError>

Called when the patch is loaded and validated but before activation

fn teardown(&mut self)

Called when the patch is being unloaded or rolled back

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors